KCustomFullScreen class

Inheritance

Constructors

KCustomFullScreen()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(BuildContext context, VideoController controller) → void
用户点击视图上的icon按钮时,将调用此方法
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(BuildContext context, VideoController controller) → Future<Object>
您需要返回一个异步事件(通常是等待页面结束的异步事件) 请参考VideoController.customFullScreen的example
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited